@@ -1,4 +1,4 @@
-binomial.CARar2 <- function(formula, data=NULL, trials, W, burnin, n.sample, thin=1,  prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, rho.S=NULL, rho.T=NULL, MALA=FALSE, verbose=TRUE)
+binomial.CARar2 <- function(formula, data=NULL, trials, W, burnin, n.sample, thin=1,  prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, rho.S=NULL, rho.T=NULL, MALA=TRUE, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -427,18 +427,18 @@ residuals <- data.frame(response=response.residuals, pearson=pearson.residuals)
   
 #### Create a summary object
 samples.beta.orig <- mcmc(samples.beta.orig)
-summary.beta <- t(apply(samples.beta.orig, 2, quantile, c(0.5, 0.025, 0.975))) 
+summary.beta <- t(rbind(apply(samples.beta.orig, 2, mean), apply(samples.beta.orig, 2, quantile, c(0.025, 0.975)))) 
 summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(accept.beta,p), effectiveSize(samples.beta.orig), geweke.diag(samples.beta.orig)$z)
 rownames(summary.beta) <- colnames(X)
-colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
+colnames(summary.beta) <- c("Mean", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
   
   summary.hyper <- array(NA, c(4, 7))    
   rownames(summary.hyper) <- c("tau2", "rho.S", "rho1.T", "rho2.T")     
-  summary.hyper[1,1:3] <- quantile(samples.tau2, c(0.5, 0.025, 0.975))
+  summary.hyper[1,1:3] <- c(mean(samples.tau2), quantile(samples.tau2, c(0.025, 0.975)))
   summary.hyper[1, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.tau2)), geweke.diag(mcmc(samples.tau2))$z)     
   if(!fix.rho.S)
   {
-    summary.hyper[2, 1:3] <- quantile(samples.rho, c(0.5, 0.025, 0.975))
+    summary.hyper[2, 1:3] <- c(mean(samples.rho), quantile(samples.rho, c(0.025, 0.975)))
     summary.hyper[2, 4:7] <- c(n.keep, accept.rho, effectiveSize(samples.rho), geweke.diag(samples.rho)$z)
   }else
   {
@@ -447,9 +447,9 @@ colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "
   }
   if(!fix.rho.T)
   {
-    summary.hyper[3, 1:3] <- quantile(samples.alpha[ ,1], c(0.5, 0.025, 0.975))
+    summary.hyper[3, 1:3] <- c(mean(samples.alpha[ ,1]), quantile(samples.alpha[ ,1], c(0.025, 0.975)))
     summary.hyper[3, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.alpha[ ,1])), geweke.diag(mcmc(samples.alpha[ ,1]))$z)
-    summary.hyper[4, 1:3] <- quantile(samples.alpha[ ,2], c(0.5, 0.025, 0.975))
+    summary.hyper[4, 1:3] <- c(mean(samples.alpha[ ,2]), quantile(samples.alpha[ ,2], c(0.025, 0.975)))
     summary.hyper[4, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.alpha[ ,2])), geweke.diag(mcmc(samples.alpha[ ,2]))$z)  
   }else
   {
