@@ -1,4 +1,4 @@
-poisson.CARanova <- function(formula, data=NULL, W, interaction=TRUE, burnin, n.sample, thin=1,  prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, rho.S=NULL, rho.T=NULL, MALA=FALSE, verbose=TRUE)
+poisson.CARanova <- function(formula, data=NULL, W, interaction=TRUE, burnin, n.sample, thin=1,  prior.mean.beta=NULL, prior.var.beta=NULL, prior.tau2=NULL, rho.S=NULL, rho.T=NULL, MALA=TRUE, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -596,18 +596,18 @@ samples.beta.orig <- common.betatransform(samples.beta, X.indicator, X.mean, X.s
 
 #### Create a summary object
 samples.beta.orig <- mcmc(samples.beta.orig)
-summary.beta <- t(apply(samples.beta.orig, 2, quantile, c(0.5, 0.025, 0.975))) 
+summary.beta <- t(rbind(apply(samples.beta.orig, 2, mean), apply(samples.beta.orig, 2, quantile, c(0.025, 0.975)))) 
 summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(accept.beta,p), effectiveSize(samples.beta.orig), geweke.diag(samples.beta.orig)$z)
 rownames(summary.beta) <- colnames(X)
-colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
+colnames(summary.beta) <- c("Mean", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
 
 
     if(interaction)
     {
     summary.hyper <- array(NA, c(5, 7))     
-    summary.hyper[1,1:3] <- quantile(samples.tau2[ ,1], c(0.5, 0.025, 0.975))
-    summary.hyper[2,1:3] <- quantile(samples.tau2[ ,2], c(0.5, 0.025, 0.975))
-    summary.hyper[3,1:3] <- quantile(samples.tau2[ ,3], c(0.5, 0.025, 0.975))
+    summary.hyper[1,1:3] <- c(mean(samples.tau2[ ,1]), quantile(samples.tau2[ ,1], c(0.025, 0.975)))
+    summary.hyper[2,1:3] <- c(mean(samples.tau2[ ,2]), quantile(samples.tau2[ ,2], c(0.025, 0.975)))
+    summary.hyper[3,1:3] <- c(mean(samples.tau2[ ,3]), quantile(samples.tau2[ ,3], c(0.025, 0.975)))
     rownames(summary.hyper) <- c("tau2.S", "tau2.T", "tau2.I", "rho.S", "rho.T")     
     summary.hyper[1, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.tau2[ ,1])), geweke.diag(mcmc(samples.tau2[ ,1]))$z)     
     summary.hyper[2, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.tau2[ ,2])), geweke.diag(mcmc(samples.tau2[ ,2]))$z)   
@@ -615,7 +615,7 @@ colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "
     
         if(!fix.rho.S)
         {
-        summary.hyper[4, 1:3] <- quantile(samples.rho, c(0.5, 0.025, 0.975))
+        summary.hyper[4, 1:3] <- c(mean(samples.rho), quantile(samples.rho, c(0.025, 0.975)))
         summary.hyper[4, 4:7] <- c(n.keep, accept.rho, effectiveSize(samples.rho), geweke.diag(samples.rho)$z)
         }else
         {
@@ -625,7 +625,7 @@ colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "
     
         if(!fix.rho.T)
         {
-        summary.hyper[5, 1:3] <- quantile(samples.lambda, c(0.5, 0.025, 0.975))
+        summary.hyper[5, 1:3] <- c(mean(samples.lambda), quantile(samples.lambda, c(0.025, 0.975)))
         summary.hyper[5, 4:7] <- c(n.keep, accept.lambda, effectiveSize(samples.lambda), geweke.diag(samples.lambda)$z)
         }else
         {
@@ -635,15 +635,15 @@ colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "
     }else
     {
     summary.hyper <- array(NA, c(4, 7))     
-    summary.hyper[1,1:3] <- quantile(samples.tau2[ ,1], c(0.5, 0.025, 0.975))
-    summary.hyper[2,1:3] <- quantile(samples.tau2[ ,2], c(0.5, 0.025, 0.975))
+    summary.hyper[1,1:3] <- c(mean(samples.tau2[ ,1]), quantile(samples.tau2[ ,1], c(0.025, 0.975)))
+    summary.hyper[2,1:3] <- c(mean(samples.tau2[ ,2]), quantile(samples.tau2[ ,2], c(0.025, 0.975)))
     rownames(summary.hyper) <- c("tau2.S", "tau2.T",  "rho.S", "rho.T")     
     summary.hyper[1, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.tau2[ ,1])), geweke.diag(mcmc(samples.tau2[ ,1]))$z)     
     summary.hyper[2, 4:7] <- c(n.keep, 100, effectiveSize(mcmc(samples.tau2[ ,2])), geweke.diag(mcmc(samples.tau2[ ,2]))$z)   
     
         if(!fix.rho.S)
         {
-        summary.hyper[3, 1:3] <- quantile(samples.rho, c(0.5, 0.025, 0.975))
+        summary.hyper[3, 1:3] <- c(mean(samples.rho), quantile(samples.rho, c(0.025, 0.975)))
         summary.hyper[3, 4:7] <- c(n.keep, accept.rho, effectiveSize(samples.rho), geweke.diag(samples.rho)$z)
         }else
         {
@@ -653,7 +653,7 @@ colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "
     
         if(!fix.rho.T)
         {
-        summary.hyper[4, 1:3] <- quantile(samples.lambda, c(0.5, 0.025, 0.975))
+        summary.hyper[4, 1:3] <- c(mean(samples.lambda), quantile(samples.lambda, c(0.025, 0.975)))
         summary.hyper[4, 4:7] <- c(n.keep, accept.lambda, effectiveSize(samples.lambda), geweke.diag(samples.lambda)$z)
         }else
         {
