@@ -1,4 +1,4 @@
-poisson.MVCARar1 <- function(formula, data=NULL,  W, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.Sigma.df=NULL, prior.Sigma.scale=NULL, rho.S=NULL, rho.T=NULL, MALA=FALSE, verbose=TRUE)
+poisson.MVCARar1 <- function(formula, data=NULL,  W, burnin, n.sample, thin=1, prior.mean.beta=NULL, prior.var.beta=NULL, prior.Sigma.df=NULL, prior.Sigma.scale=NULL, rho.S=NULL, rho.T=NULL, MALA=TRUE, verbose=TRUE)
 {
 ##############################################
 #### Format the arguments and check for errors
@@ -80,12 +80,13 @@ N <- NK / K
 #### Priors
   if(is.null(prior.mean.beta)) prior.mean.beta <- rep(0, p)
   if(is.null(prior.var.beta)) prior.var.beta <- rep(100000, p)
-  if(is.null(prior.Sigma.df)) prior.Sigma.df <- J+1
-  if(is.null(prior.Sigma.scale)) prior.Sigma.scale <- diag(rep(1/1000,J))
+  if(is.null(prior.Sigma.df)) prior.Sigma.df <- 2
+  if(is.null(prior.Sigma.scale)) prior.Sigma.scale <- rep(100000, J)
 prior.beta.check(prior.mean.beta, prior.var.beta, p)
-common.prior.varmat.check(prior.Sigma.scale, J)  
-  
-  
+    if(!is.numeric(prior.Sigma.scale)) stop("prior.Sigma.scale has non-numeric values.", call.=FALSE)    
+    if(sum(is.na(prior.Sigma.scale))!=0) stop("prior.Sigma.scale has missing values.", call.=FALSE)   
+
+
 #### Compute the blocking structure for beta     
 block.temp <- common.betablock(p)
 beta.beg  <- block.temp[[1]]
@@ -124,6 +125,7 @@ phi.vec <- rnorm(n=N.all, mean=0, sd=res.sd)
 phi <- matrix(phi.vec, ncol=J, byrow=TRUE)
 Sigma <- cov(phi)
 Sigma.inv <- solve(Sigma)
+Sigma.a <- rep(1, J)
 regression <- X.standardised %*% beta
 fitted <- exp(regression + phi + offset)
   
@@ -136,6 +138,7 @@ n.keep <- floor((n.sample - burnin)/thin)
 samples.beta <- array(NA, c(n.keep, J*p))
 samples.phi <- array(NA, c(n.keep, N.all))
 samples.Sigma <- array(NA, c(n.keep, J, J))
+samples.Sigma.a <- array(NA, c(n.keep, J))
   if(!fix.rho.S) samples.rho <- array(NA, c(n.keep, 1))
   if(!fix.rho.T) samples.alpha <- array(NA, c(n.keep, 1))
 samples.loglike <- array(NA, c(n.keep, N.all))
@@ -149,7 +152,8 @@ accept.beta <- rep(0,2*J)
 proposal.sd.beta <- rep(0.01, J)
 proposal.sd.phi <- 0.1
 proposal.sd.rho <- 0.02
-Sigma.post.df <- prior.Sigma.df + K * N  
+Sigma.post.df <- prior.Sigma.df + J - 1 + K * N  
+Sigma.a.post.shape <- (prior.Sigma.df + J) / 2
 
 
 
@@ -186,13 +190,13 @@ islands <- W.islands$comp.id
 n.islands <- max(W.islands$nc)
   if(rho==1 & alpha==1) 
   {
-  Sigma.post.df <- prior.Sigma.df + ((N-1) * (K-n.islands))/2
+  Sigma.post.df <- prior.Sigma.df + ((N-1) * (K-n.islands)) + J - 1
   }else if(rho==1)
   {
-  Sigma.post.df <- prior.Sigma.df + (N * (K-n.islands))/2        
+  Sigma.post.df <- prior.Sigma.df + (N * (K-n.islands)) + J - 1        
   }else if(alpha==1)
   {
-  Sigma.post.df <- prior.Sigma.df + ((N-1) * K)/2          
+  Sigma.post.df <- prior.Sigma.df + ((N-1) * K) + J - 1          
   }else
   {}
 
@@ -275,7 +279,7 @@ n.islands <- max(W.islands$nc)
     ####################
     ## Sample from Sigma
     ####################
-    Sigma.post.scale <- prior.Sigma.scale + t(phi[1:K, ]) %*% Q %*% phi[1:K, ]
+    Sigma.post.scale <- 2 * prior.Sigma.df * diag(1 / Sigma.a) + t(phi[1:K, ]) %*% Q %*% phi[1:K, ]
       for(t in 2:N)
       {
       phit <- phi[((t-1)*K+1):(t*K), ]
@@ -286,6 +290,14 @@ n.islands <- max(W.islands$nc)
     Sigma <- riwish(Sigma.post.df, Sigma.post.scale)
     Sigma.inv <- solve(Sigma)
 
+        
+
+    ######################
+    ## Sample from Sigma.a
+    ######################
+    Sigma.a.posterior.scale <- prior.Sigma.df * diag(Sigma.inv) + 1 / prior.Sigma.scale^2
+    Sigma.a <- 1 / rgamma(J, Sigma.a.post.shape, scale=(1/Sigma.a.posterior.scale))   
+
     
     
     ######################
@@ -354,6 +366,7 @@ n.islands <- max(W.islands$nc)
       samples.beta[ele, ] <- as.numeric(beta)
       samples.phi[ele, ] <- as.numeric(t(phi))
       samples.Sigma[ele, , ] <- Sigma
+      samples.Sigma.a[ele, ] <- Sigma.a
       if(!fix.rho.S) samples.rho[ele, ] <- rho
       if(!fix.rho.T) samples.alpha[ele, ] <- alpha
       samples.loglike[ele, ] <- loglike
@@ -457,7 +470,7 @@ n.islands <- max(W.islands$nc)
   
   #### Create a summary object
   samples.beta.orig <- mcmc(samples.beta.orig)
-  summary.beta <- t(apply(samples.beta.orig, 2, quantile, c(0.5, 0.025, 0.975))) 
+  summary.beta <- t(rbind(apply(samples.beta.orig, 2, mean), apply(samples.beta.orig, 2, quantile, c(0.025, 0.975)))) 
   summary.beta <- cbind(summary.beta, rep(n.keep, p), rep(accept.beta,p), effectiveSize(samples.beta.orig), geweke.diag(samples.beta.orig)$z)
   col.name <- rep(NA, p*(J-1))
 
@@ -475,10 +488,10 @@ n.islands <- max(W.islands$nc)
     }
   }
   rownames(summary.beta) <- col.name
-  colnames(summary.beta) <- c("Median", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
+  colnames(summary.beta) <- c("Mean", "2.5%", "97.5%", "n.sample", "% accept", "n.effective", "Geweke.diag")
   
   summary.hyper <- array(NA, c((J+2) ,7))
-  summary.hyper[1:J, 1] <- diag(apply(samples.Sigma, c(2,3), quantile, c(0.5)))
+  summary.hyper[1:J, 1] <- diag(apply(samples.Sigma, c(2,3), mean))
   summary.hyper[1:J, 2] <- diag(apply(samples.Sigma, c(2,3), quantile, c(0.025)))
   summary.hyper[1:J, 3] <- diag(apply(samples.Sigma, c(2,3), quantile, c(0.975)))
   summary.hyper[1:J, 4] <- rep(n.keep, J)
@@ -491,7 +504,7 @@ n.islands <- max(W.islands$nc)
   
     if(!fix.rho.S)
     {
-    summary.hyper[(J+1), 1:3] <- quantile(samples.rho, c(0.5, 0.025, 0.975))
+    summary.hyper[(J+1), 1:3] <- c(mean(samples.rho), quantile(samples.rho, c(0.025, 0.975)))
     summary.hyper[(J+1), 4:5] <- c(n.keep, accept.rho)
     summary.hyper[(J+1), 6:7] <- c(effectiveSize(samples.rho), geweke.diag(samples.rho)$z)
     }else
@@ -503,7 +516,7 @@ n.islands <- max(W.islands$nc)
   
     if(!fix.rho.T)
     {
-    summary.hyper[(J+2), 1:3] <- quantile(samples.alpha, c(0.5, 0.025, 0.975))
+    summary.hyper[(J+2), 1:3] <- c(mean(samples.alpha), quantile(samples.alpha, c(0.025, 0.975)))
     summary.hyper[(J+2), 4:5] <- c(n.keep, accept.alpha)
     summary.hyper[(J+2), 6:7] <- c(effectiveSize(samples.alpha), geweke.diag(samples.alpha)$z)
     }else
